summaryrefslogtreecommitdiffstats
path: root/amarok/src/playerwindow.cpp
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
commiteb88625a55dbaa7e92042d96241e9ddda4604862 (patch)
tree4c27a5cdb55479be9713df0175bf0fef29c2cbf2 /amarok/src/playerwindow.cpp
parent1dbf3ff1cbb6d82a451bc319301bf38816c2c232 (diff)
downloadamarok-eb88625a55dbaa7e92042d96241e9ddda4604862.tar.gz
amarok-eb88625a55dbaa7e92042d96241e9ddda4604862.zip
rename the following methods:
tqparent parent tqmask mask git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/applications/amarok@1246260 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'amarok/src/playerwindow.cpp')
-rw-r--r--amarok/src/playerwindow.cpp30
1 files changed, 15 insertions, 15 deletions
diff --git a/amarok/src/playerwindow.cpp b/amarok/src/playerwindow.cpp
index 3e501d3d..91e03f9f 100644
--- a/amarok/src/playerwindow.cpp
+++ b/amarok/src/playerwindow.cpp
@@ -71,16 +71,16 @@ using Amarok::getPNG;
//fairly pointless template which was designed to make the ctor clearer,
//but probably achieves the opposite. Still, the code is neater..
template<class W> static inline W*
-createWidget( const TQRect &r, TQWidget *tqparent, const char *name = 0, TQt::WFlags f = 0 )
+createWidget( const TQRect &r, TQWidget *parent, const char *name = 0, TQt::WFlags f = 0 )
{
- W *w = new W( tqparent, name, f );
+ W *w = new W( parent, name, f );
w->setGeometry( r );
return w;
}
-PlayerWidget::PlayerWidget( TQWidget *tqparent, const char *name, bool enablePlaylist )
- : TQWidget( tqparent, name, TQt::WType_TopLevel )
+PlayerWidget::PlayerWidget( TQWidget *parent, const char *name, bool enablePlaylist )
+ : TQWidget( parent, name, TQt::WType_TopLevel )
, EngineObserver( EngineController::instance() )
, m_minimalView( false )
, m_pAnimTimer( new TQTimer( this ) )
@@ -95,7 +95,7 @@ PlayerWidget::PlayerWidget( TQWidget *tqparent, const char *name, bool enablePla
// Sets caption and icon correctly (needed e.g. for GNOME)
kapp->setTopWidget( this );
- tqparent->installEventFilter( this ); //for hidePLaylistWithMainWindow mode
+ parent->installEventFilter( this ); //for hidePLaylistWithMainWindow mode
//if this is the first time we have ever been run we let KWin place us
if ( AmarokConfig::playerPos() != TQPoint(-1,-1) )
@@ -182,7 +182,7 @@ PlayerWidget::PlayerWidget( TQWidget *tqparent, const char *name, bool enablePla
m_pPlaylistButton = new IconButton( this, "pl", TQT_SIGNAL(playlistToggled( bool )) );
m_pPlaylistButton->setGeometry( 5,85, 28,13 );
- m_pPlaylistButton->setOn( tqparent->isShown() || enablePlaylist );
+ m_pPlaylistButton->setOn( parent->isShown() || enablePlaylist );
m_pDescription = createWidget<TQLabel>( TQRect(4,6, 250,10), this );
@@ -549,7 +549,7 @@ bool PlayerWidget::event( TQEvent *e )
case 6/*TQEvent::KeyPress*/:
if (TQT_TQKEYEVENT(e)->key() == TQt::Key_D/* && (m_pAnalyzer->inherits(TQGLWIDGET_OBJECT_NAME_STRING)*/)
{
- if( m_pAnalyzer->tqparent() )
+ if( m_pAnalyzer->parent() )
{
m_pAnalyzer->reparent( 0, TQPoint(50,50), true );
m_pAnalyzer->setCaption( kapp->makeStdCaption( i18n("Analyzer") ) );
@@ -676,7 +676,7 @@ bool PlayerWidget::event( TQEvent *e )
bool
PlayerWidget::eventFilter( TQObject *o, TQEvent *e )
{
//NOTE we only monitor for tqparent() - which is the PlaylistWindow
if( TQT_BASE_OBJECT(o) == TQT_BASE_OBJECT(m_pAnalyzer) )
{
@@ -839,8 +839,8 @@ void PlayerWidget::slotShowEqualizer( bool show ) //SLOT
#include <kiconeffect.h>
#include <kimageeffect.h>
-NavButton::NavButton( TQWidget *tqparent, const TQString &icon, KAction *action )
- : TQToolButton( tqparent )
+NavButton::NavButton( TQWidget *parent, const TQString &icon, KAction *action )
+ : TQToolButton( parent )
, m_glowIndex( 0 )
{
// Prevent flicker
@@ -925,19 +925,19 @@ void NavButton::drawButtonLabel( TQPainter* p )
// CLASS IconButton
//////////////////////////////////////////////////////////////////////////////////////////
-IconButton::IconButton( TQWidget *tqparent, const TQString &icon, const char *signal )
- : TQButton( tqparent )
+IconButton::IconButton( TQWidget *parent, const TQString &icon, const char *signal )
+ : TQButton( parent )
, m_up( getPNG( icon + "_active2" ) ) //TODO rename files better (like the right way round for one!)
, m_down( getPNG( icon + "_inactive2" ) )
{
- connect( this, TQT_SIGNAL(toggled( bool )), tqparent, signal );
+ connect( this, TQT_SIGNAL(toggled( bool )), parent, signal );
setToggleButton( true );
setFocusPolicy( TQ_NoFocus ); //we have no way to show focus on these widgets currently
}
-IconButton::IconButton( TQWidget *tqparent, const TQString &icon, TQObject* receiver, const char *slot )
- : TQButton( tqparent )
+IconButton::IconButton( TQWidget *parent, const TQString &icon, TQObject* receiver, const char *slot )
+ : TQButton( parent )
, m_up( getPNG( icon + "_active2" ) ) //TODO rename files better (like the right way round for one!)
, m_down( getPNG( icon + "_inactive2" ) )
{
@@ -676,7 +676,7 @@ bool PlayerWidget::event( TQEvent *e )
PlayerWidget::eventFilter( TQObject *o, TQEvent *e )
{
- //NOTE we only monitor for tqparent() - which is the PlaylistWindow
+ //NOTE we only monitor for parent() - which is the PlaylistWindow
if( TQT_BASE_OBJECT(o) == TQT_BASE_OBJECT(m_pAnalyzer) )
{